{% extends widget.get_base_template %}

{% block content %}
<ul class="vertical">
{% for link in widget.list.link_set.all %}
	<li><a href="{{ link.web_address }}" class="{% if link.target == '_modal' %}ajax-modal modal{% endif %} {% if link.target == '_blank' %}blank{% endif %}">{{ link }}</a></li>
{% endfor %}
</ul>
{% endblock %}
