{% extends widget.get_base_template %}

{% load thumbnail %}

{% block content %}
<ul class="horizontal">
	{% for link in widget.list.link_set.all %}
	<li>
		<a href="{{ link.web_address }}" class="{% if link.target == '_modal' %}modal ajax-modal{% endif %} {% if link.target == '_blank' %}blank{% endif %}">
			{% thumbnail link.image.file "250x48" format="PNG" as image %}
			<img src="{{ image.url }}" alt="" /><br />
			{% empty %}
			<span>{{ link }}</span>
			{% endthumbnail %}
		</a>
	</li>
	{% endfor %}
</ul>
{% endblock %}
