{% extends widget.get_base_template %}

{% load i18n %}

{% block content %}
<div class="button-wrapper-outer">
	<div class="button-wrapper">
		<div class="button-wrapper-inner">
			<a href="{% if widget.link %}{{ widget.link.web_address }}{% else %}{{ widget.alt_link|default:"#" }}{% endif %}" class="{% if widget.on_click == 'open_modal' %}ajax-modal {% endif %}button {% if widget.size == 'large' %}{% if widget.priority == 'primary' %}button-primary-large{% else %}button-secondary-large{% endif %}{% else %}{% if widget.priority != 'primary' %}button-secondary{% endif %}{% endif %} f-{{ widget.alignment }}"><span><span>{% if widget.text %}{{ widget.text }}{% else %}{% trans "More" %}{% endif %}</span></span></a>
		</div>
	</div>
</div>
{% endblock %}
