{% extends widget.get_base_template %}

{% block content %}
<ul class="horizontal">
{% for link in widget.list.link_set.all %}
	<li>
		<a href="{{ link.web_address }}" class="{% if link.target == '_modal' %}ajax-modal modal{% endif %} {% if link.target == '_blank' %}blank{% endif %}">
			<span>{{ link }}</span>
		</a>
	</li>
{% endfor %}
</ul>
{% endblock %}
